@@ -7,7 +7,10 @@ from allure import step
 
 
 def get_settings(environment):
-    ROOT_DIR = Path(__file__).parent.parent.parent.parent.parent.parent
+    if system().lower() in ['linux', 'macos']:
+        ROOT_DIR = '/app'
+    else:
+        ROOT_DIR = Path(__file__).parent.parent.parent.parent.parent.parent
     CONFIG_PATH = join(ROOT_DIR, 'config/config.json')
     with open(CONFIG_PATH) as data:
         config = json.load(data)
@@ -35,7 +38,10 @@ def get_count_tests(reporter):
 
 
 def get_fixtures():
-    fixtures = join(Path(__file__).parent.parent.parent.parent.parent.parent, 'fixtures')
+    if system().lower() in ['linux', 'macos']:
+        fixtures = join('/app', 'fixtures')
+    else:
+        fixtures = join(Path(__file__).parent.parent.parent.parent.parent.parent, 'fixtures')
     file_path = []
     for file in glob(f'{fixtures}/*'):
         file = file.split('/') if system().lower() in ['linux', 'macos'] else file.split('\\')
